contracts\_lib\_py.templates.template\_base module
==================================================

.. automodule:: contracts_lib_py.templates.template_base
   :members:
   :undoc-members:
   :show-inheritance:
